from .__pytransform import pyarmor_runtime

"""
# MixtureMapping

[![Documentation](https://github.com/VK/dash-express-components/workflows/Publish%20release/badge.svg)](https://vk.github.io/mixturemapping-doc)
[![PyPI version](https://badge.fury.io/py/mixturemapping.svg)](https://badge.fury.io/py/mixturemapping)

Train Gaussian Mixture Mappings


## Provides:
  1. Layers to build tensorflow models to map Gaussian mixtures
  2. Tools to compute yield values of Gaussian mixtures in complex binning schemes

## Example
  
    import mixturemapping as mm  
    import tensorflow as tf

    inMeans = tf.keras.Input(shape=(mixN, inputMixM), name="Means", dtype=dataType)
    inStdDevs = tf.keras.Input(shape=(mixN, inputMixM), name="StdDevs", dtype=dataType)
    inWeight = tf.keras.Input(shape=(mixN), name="Weights", dtype=dataType)

    mapModel = tf.keras.Sequential()
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(outputMixM))
    y = mapModel(inMeans)

    deltaModel = tf.keras.Sequential()
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(outputMixM))
    yDelta = deltaModel(inMeans)

    covALayer = mm.layers.TrainableCovMatrix(outputMixM, name="CovA")
    covA = covALayer(inMeans)

    mapLayer = mm.layers.GeneralMapping(outputMixM, name="Mapping", dtype=dataType)
    newDist = mapLayer({'means': inMeans, 'y':y, 'yDelta':yDelta, 'stdDevs': inStdDevs, 'weights': inWeight, 'covA': covA})

    distLayer = mm.layers.Distribution(dtype=dataType, regularize_cov_epsilon=0.95)
    dist = distLayer(newDist)

### Developement
```
$ py -m venv env
$ .\env\Scripts\activate
$ pip install -r requirements.txt
```


"""


pyarmor_runtime()
__pyarmor__(__name__, __file__, b'\x50\x59\x41\x52\x4d\x4f\x52\x00\x00\x03\x09\x00\x61\x0d\x0d\x0a\x08\x2d\xa0\x01\x00\x00\x00\x00\x01\x00\x00\x00\x40\x00\x00\x00\x8d\x08\x00\x00\x00\x00\x00\x18\xb4\x7a\x4c\x9b\x40\x00\x32\xdc\x2e\x75\x16\x1a\xd0\x07\x3c\x53\x00\x00\x00\x00\x00\x00\x00\x00\x55\x51\x4d\x5b\x5a\x0b\x96\x82\x2a\xbe\xe0\xe1\xbc\xe2\xaa\xa0\x30\x83\x82\xa6\xc5\xf0\x96\xc1\x9d\x46\xae\x67\x67\xf5\xac\x20\x69\x51\xdf\x12\x33\x92\xf0\xbb\xa0\x76\x85\x05\x77\x0e\x2d\xc0\x37\x45\x17\x82\x4f\x8c\x96\xca\xeb\xed\xfc\x90\x2c\x9f\xec\x6b\x5e\x4e\x4a\x21\x5a\x1b\x6f\xea\xf6\xa6\x8d\x22\xf9\x36\x85\x55\x99\x2a\x5c\xd3\xa3\x2d\x1b\xf3\xbd\xf1\xcd\x58\x0d\xa1\xe2\xb0\x01\xb7\x87\x88\x5e\x92\xb0\x9e\x9b\xe5\xd5\x52\xa4\x1a\x5f\xc7\xad\x78\x96\x52\x9c\xfa\xf7\x1a\x7e\x43\xba\xa3\x3c\x47\x09\xb2\xb5\x70\x75\x0d\x68\x69\x79\xec\xc1\x0d\x91\x94\x33\x6c\x82\x35\x95\x13\x91\xbd\x50\x16\x6a\xff\x3c\xa7\xcb\x35\x01\x3f\xb6\x2b\x2d\xa5\xf9\x7d\xf7\x93\x97\x9b\xa8\x4e\x08\x42\x65\xc6\x65\xfb\x4f\xda\x7d\x64\x68\x2f\x24\x4c\x50\x65\xc4\x88\x20\xeb\x35\x00\xf3\xcb\x0c\x43\x22\x9f\x68\x7e\x6c\xd5\x56\xe4\xb2\xc8\xe5\xf7\x07\xcc\x3b\x78\x93\xf0\x47\x94\xe9\x12\x4c\xeb\xfd\x67\xc6\xc8\xfc\x27\xdd\x82\x15\x66\xcb\xf9\x9e\xd0\xb0\xe0\x87\x05\xbb\x7e\x9e\x4d\xb7\x7a\x6a\x76\xa4\x05\x31\xb4\xac\xb6\x8e\xf0\x71\x29\x0e\x72\x7c\x79\x4f\xaa\x2e\x3f\x7e\x5f\x41\xc8\x32\x46\xcd\x8b\x5c\xc3\x26\x40\xaa\x06\xbe\x1f\x70\xda\x4e\x5f\x55\xb1\x0b\x4e\x86\xa1\xea\xa1\x19\x3b\x07\xde\x24\x04\xc4\x2f\x08\x84\xb9\x84\xf5\x6c\x49\xa7\xb4\x33\x9f\x28\x0a\x2e\xc0\x88\xba\x1c\x5c\x0b\xe4\x8e\x62\x9d\x8e\x84\xa1\x19\x05\xfc\xe1\xe0\xf2\x31\x07\x18\x78\xd4\xa7\x77\x78\x2a\xa5\xdd\xcb\x82\x0b\x36\x22\xf4\x5d\x57\xcf\x3b\x81\x0c\x78\x49\xc8\x5f\x34\x98\x76\xeb\xf5\x6d\x87\xd8\x28\xf1\x5f\xac\x6b\xbb\xba\x3f\x78\xad\x73\xf7\x15\x0d\x64\xab\x9a\x16\x66\xa2\xca\x25\xa7\x24\x9d\x8b\xea\xf9\x1a\x9c\x9e\x33\xe9\xe8\xb7\x67\xb4\x84\x09\xad\x74\x84\x62\x42\x14\x73\x27\x97\x55\x1c\xb4\x36\x53\x5a\xb0\x6e\x6a\xb0\xd2\x01\x3a\x16\xed\x3a\x67\xac\x5c\x9f\x6b\x79\x2b\xed\x6a\xa7\xf9\xdb\xa6\xfc\x93\x1b\x46\x8d\x9a\xbb\xf8\x44\xa7\x9b\x50\x7f\x30\x09\xe3\xea\xe9\x42\xa5\x41\x4b\xa2\xf6\xbe\xa6\x03\x53\x9a\x75\x75\x12\xae\xf4\x68\x02\xb0\x92\xa1\x5e\x7c\xe8\x31\x97\xe3\x4f\xb5\xee\xe9\x15\x7f\x0b\x8a\xb9\x08\x0f\xf7\x95\x10\x6f\x29\x7d\x4a\xbb\x95\x3c\x4e\xb6\x01\xb7\x78\x32\x56\x7f\x3b\xee\x99\x16\x41\xff\x9b\x2c\x2c\x9d\xa8\xc6\xc5\x5b\xf1\x77\x08\xc6\xba\xd3\x29\x8b\xbd\x7d\xa8\x5f\xe9\x80\x66\xc5\x4b\x87\xe1\x1c\x6c\x00\xae\x3d\x60\x85\x51\x20\xcf\xb4\x98\x52\x01\x29\x83\xaa\x58\x48\x15\xb1\xb8\xa7\x22\x62\x85\xe1\x81\x33\x56\x86\x42\x58\xd4\x0d\xa2\x3c\x91\x6d\x07\xda\x02\x35\x2a\xcb\xa3\x1d\x93\x1c\x5b\x3d\xeb\xb3\x6e\x4e\x2b\xb2\x20\x26\x61\x5b\xa5\xa5\x4f\x66\x5d\x50\x41\x3d\xd0\xd2\x0e\xe5\x6c\x66\x2e\xa9\xc0\x72\x46\xe0\x3c\x34\x00\x49\xf9\x8d\x42\x24\xef\x51\x0b\x72\x43\xdc\x83\x3b\xf1\xb4\xd2\xb3\xb0\x4b\x3a\x62\x03\xf2\xc0\x24\xe2\xbb\x68\xd4\x9f\x83\xa7\x40\xda\x3e\xb7\x98\x67\x13\x01\x3b\x49\xd9\x0d\x08\x00\x6e\x57\x4a\x26\xdb\x5f\xaf\xab\xca\xf0\x60\x09\xd3\xcc\x8a\xc6\x74\x06\x8f\x7a\xf8\xa1\xd8\x93\xcf\x23\xcf\x5c\x28\x4c\x1d\x54\xa1\x49\xd1\x6d\x5f\x3d\xf6\xb6\x77\xa9\x3c\x7a\x3b\x68\x7d\x0c\x39\xc2\x14\xe5\xbb\x6f\xce\xc7\x97\xde\xc2\x4e\xa8\x4e\x3b\xa3\x34\x7b\x06\xe0\x28\xa1\xa2\xc0\x14\xad\xc6\xd2\xd7\x28\x09\x47\x91\x71\x83\x1b\xf0\x57\x15\x91\x1c\xa5\x34\xc6\x3c\x1d\xb7\x3d\x35\xe6\x3b\xc0\x94\xc6\xc9\x85\x5b\xf8\x7d\x25\xe3\xfd\x8b\x77\x4c\x2e\xcb\x2d\xaf\x44\xae\xaa\xcb\x38\xe1\x66\x84\x85\x15\xba\x29\xaf\xbe\x96\x04\x69\x0a\x88\x41\x9b\x8e\x64\x16\x92\x0e\x4c\x25\x13\x3a\x71\x9e\x68\x05\x7e\x0a\xcd\x57\x48\xd5\x31\xe2\xd9\xca\xf4\x54\xf1\x26\xd1\x4d\xba\x0d\x52\x0f\x16\xaa\x93\x01\x30\xf4\xb0\xf9\x63\xc3\xe7\xeb\x7e\x54\x4d\xe3\x2e\xb1\xa1\x0d\xb3\xe6\x3b\xd1\xf8\x34\x8d\x4a\x69\x9f\x59\xee\xfa\x6f\xb6\xce\x98\x85\xe8\x29\x48\xc8\xc9\x5d\xe7\x67\x0d\xeb\x5c\x53\xbf\x6f\xfb\x40\xa0\xb7\x0d\xf6\x05\x57\x66\xd3\xe2\x9f\x99\x6d\xed\x03\x21\x3f\x03\xaa\x36\x20\x18\x60\x32\x33\xa7\x1d\xcd\x85\x61\xa5\x31\x99\xfb\x3b\xad\xff\x0e\xb6\xfc\x8b\x29\x37\x38\xe6\x51\x71\x70\xf6\xb3\xb3\x07\x47\x88\xca\x91\x58\x51\xa6\x20\xb7\x64\xc4\xd1\x9d\x79\x04\xf5\xb1\x12\xbc\xee\xa0\x3b\x31\xc2\x93\x46\xe9\x8b\x50\xe4\xcd\xd6\xe3\x10\x8c\x32\x8b\x55\x24\x9b\x3a\xe9\x2b\x61\x38\x89\x65\xb0\x86\x38\xa3\xd5\x39\x39\x69\x67\x5a\x8e\x11\xaa\xd9\x47\x4d\xfd\x64\xe1\x0d\xd8\x12\x2f\x3e\x89\x13\x0b\x7f\x2f\x5c\xda\x5d\x57\xa9\x9b\x03\xb6\x02\x2a\x9e\x66\xbc\xc2\xe7\x7d\xd3\xcd\x0e\x67\x4f\x22\x78\x00\x7b\x01\x96\xac\x49\x0b\x1d\xe5\x86\x40\xdb\x8f\x6f\x5e\xdc\xaa\x2b\x09\x33\xea\x17\x55\x3c\x72\xbc\x95\x3c\x27\x74\xf4\x36\xf2\x8a\xcb\x3d\x79\x68\xe1\x19\x78\x87\x5d\xb8\x50\xbc\x90\x5a\x23\x63\x00\x8d\xc2\x2c\x24\xe0\xe0\xc0\x81\x85\x9b\xcd\x1d\x13\x6c\x55\x61\x22\x71\x01\x83\x6c\x23\x36\xb0\x6a\x46\xe3\xf7\x10\xd8\x51\xc5\xd0\xbb\xd8\xa5\x49\xef\x07\x38\xaa\xc3\x94\x29\x42\x45\x6c\x83\x8b\x2e\xab\xe5\x57\xae\x10\x1f\xf3\xce\xfa\x78\xd8\xa2\x0a\xaf\xbc\xa3\x79\x45\x78\xf0\x01\x60\x4b\xda\xee\x90\xe7\x7d\xa3\x05\x50\x5c\xe9\x7d\xaa\xf2\x0f\xe3\xba\x18\xa5\xac\x4b\xca\x1a\xdd\xfe\xe5\xe8\xd5\xb5\xd9\xc2\x05\x34\xd5\x79\xe1\x04\x1f\xaf\x45\xae\x0f\xe5\x53\x59\x40\x3a\xa9\xab\xaf\x70\x32\x9f\xef\xce\xed\x1d\xfd\x2d\xac\x49\xfa\xe0\x61\x08\x60\xca\xd0\x06\x11\x84\xbc\xc1\xac\x72\x21\xa4\x74\x2f\xbd\x90\xef\x4e\x87\x49\x5e\x66\xe8\x17\xe5\x27\xcb\x40\x5b\x0c\x51\xe3\xfa\xb4\x38\xea\x1b\xf2\xe7\xcf\x6c\xae\xad\xea\x9a\xaa\x9d\x7a\xfa\x20\x37\xeb\xed\x6b\x73\xdf\x37\xd9\x51\xe7\x3d\xac\x62\xa3\x17\x16\x5a\xba\x06\xb2\xa3\x40\x5e\x98\xf7\xfc\xe7\x3c\xb7\x23\x8a\x66\x65\x7f\xf8\x37\x3a\x1f\xe6\x0b\x55\x30\x7b\xd4\x35\x85\x5a\x67\x43\x7c\x1d\x22\x33\x10\x08\x76\x12\xd7\xb0\x15\xbd\xac\x43\xc1\x09\xb8\x1c\xc2\xa0\x09\xc6\x80\xec\x79\xd8\xa4\xab\x31\x4a\x28\x43\x62\xd3\x8b\xf9\xe4\xac\x85\xf7\x1a\x68\x45\xad\x17\x90\x0f\x87\x35\x69\xf9\x7c\xeb\x38\xe0\x9e\x2f\x03\xd4\xb9\x30\x67\x9c\x4d\x53\x1a\xf2\x3c\x5e\x63\x63\x0c\x8b\xa5\x55\x0a\xde\x79\xc8\xa2\x57\x0a\x0c\xb4\xe7\xac\xfb\x1b\x93\x7b\x24\x26\x2f\x84\xe8\x9f\xfd\x62\x23\x3f\x6a\x80\xac\xa7\x2f\x47\x9f\x4d\xa4\x17\x37\xc9\xb8\x5f\x95\x98\xa6\x46\x17\xbe\xec\x8d\xd9\x8e\xc2\xa5\x69\x3b\x4f\x05\xe6\x5c\x5c\x7c\x4d\x83\x04\x15\x2e\xe8\x50\x11\x20\x91\x64\x8f\x9b\x1e\xf3\x76\xaf\x19\x28\xdc\x35\x13\x60\x8d\x1f\xf5\x9e\xba\xfa\xb1\x30\x1c\xd2\xd5\x56\xb4\xbc\xe1\x26\x2b\xad\xda\xf1\x86\xbe\x8a\xa9\x17\x84\x03\xb7\x9b\x86\xe3\xdf\x88\xe7\x63\xc6\xe4\x4e\x92\x9a\xa6\x48\x27\x24\xe6\x28\xb8\xee\x84\xc7\x8d\xbe\x2b\x9d\x6b\x02\x04\xc3\x38\xbc\x5e\xc2\xde\xa0\xfe\x4a\x0d\x1a\x4d\xc6\x76\xc7\x9f\x26\x89\x6d\x7f\xeb\x95\xae\xc0\x2a\xdc\x87\xda\xec\xbc\x80\x89\x01\xb4\x50\x78\x44\xf6\x2d\x11\x6e\x12\x00\x4c\xe5\x6e\xe5\x20\xed\x02\x98\x02\xbb\x5e\xda\xee\xbe\xde\x81\x52\x33\xa5\x2c\xfe\x1d\xea\xfd\x25\xb6\x55\x19\x3c\x31\x72\xb6\x49\x87\xb8\xf7\x4d\x88\x62\x2e\x51\x0f\x00\x84\xbb\x1f\xde\xc0\x3f\x86\x8c\xaa\xce\x24\x99\x24\x13\xae\x2b\x1c\x44\x92\x54\x5b\x52\x17\x4e\x7d\x18\x31\x0c\x49\x3a\xe9\xba\x53\xd7\xe6\xab\x1d\xff\x80\x02\x60\x95\x68\x27\xf5\xf8\x13\xc9\x91\x4d\x17\xe6\xc1\x00\xcf\x1e\xc6\xac\x8a\xca\x10\xfd\x15\x69\x70\x5c\xc0\x41\x6a\xee\x0f\x02\x14\x78\x7c\x46\x20\xef\xfd\x08\x6e\x8d\x1a\x77\xe5\x83\x52\xd9\x3c\x8e\x24\x6f\xeb\xb7\x84\x40\x42\xe0\x05\x19\x80\xde\xf7\x86\x29\x93\xd5\x3f\x15\xff\x20\xf6\x35\x3a\xb3\x6d\xb4\xad\x8e\xbe\xeb\x7b\xe1\x41\xbc\x49\xfd\x71\xf9\xd5\xf7\x5b\x78\x1f\x57\x6d\x8a\xd2\xbc\x2f\xb1\x04\x16\x54\x35\xf7\x6c\x25\x9f\xdd\xf2\x33\x7d\x38\x52\x4c\xb8\x60\x61\x8d\xb4\x09\x7c\x20\x5c\x87\x2b\x69\xaf\xd9\xdb\x7e\xc6\xba\xe2\xd5\x4e\x00\xc2\x75\xa5\x59\xe7\xe7\xc8\x36\x6e\x06\xad\xbe\xfc\x18\x3f\x1a\x08\xf4\x07\x8c\x02\x09\x26\x38\x40\x24\x11\x3a\xc3\x7c\xa3\x66\x2d\xe6\xb0\xc7\x6b\xfb\x02\x4a\x37\x60\xd6\x7e\xc4\x5a\x93\x8d\x84\x83\xae\x12\xb2\x88\xdf\x54\xca\x02\x72\x58\x4f\x3b\x42\x14\x4e\x46\xdc\x71\x9f\x48\xd4\x24\x70\x80\x5b\x70\x26\xcc\x7c\x6a\x82\xbf\x2d\xba\x18\x06\x05\x37\x23\xb8\x27\x93\x2b\x04\x6e\x82\x47\x19\xd9\x24\xa5\x92\x85\xe0\x88\xe8\x16\xf8\xdb\x4e\xab\x65\xe3\x55\x92\x11\x90\x73\x12\xbe\x68\xbd\x3a\x17\xd8\x84\x47\xd9\xc2\xb3\x05\xc6\x2a\xbf\x48\x49\xa3\x5a\xf4\x7e\xca\x15\x5e\x61\xd9\x79\xd6\x87\xb9\x91\x7a\x56\x06\x73\x04\xa8\xbc\xd7\xa7\x00\x70\xd2\x63\xe1\x83\x46\xc5\x7a\x28\x92\xcc\xcb\x21\xec\x63\x60\x3f\x47\xdb\xad\xbe\xac\x10\xad\x0f\xb1\xc1\x0a\x47\xc4\xba\x1b\x0b\x04\xd5\x8b\x49\x80\x68\xdf\xf0\x20\x3d\x33\xa3\xe4\xff\x12\xa9\xf8\xc5\x4d\x8a\x17\x5a\x71\x57\x46\x2f\x66\x80\xb6\x74\x51\x08\x40\xb2\xe4\xa5\x3b\xe8\xac\xf7\xa0\x62\x7e\x56\xe9\xda\x15\x54\xf1\x45\xe2\xaf\x64\xfa\x96\xe2\x3e\xe0\x15\xf9\x7b\xfc\x3c\x7d\xc2\xcd\x88\xda\xf0\x6e\xb4\x9d\x55\xde\x6a\xd7\x81\x05\x5f\x07\x8e\xf1\x67\x22\x5f\x36\x8c\x88\x62\xda\x25\x00\x1a\xd5\x2b\x13\x05\x21\xf6\x60\x13\xb4\x8b\x0d\xbf\xe6\x9f\x42\x20\xb5\xb6\x9d\x82\x94\x02\xaa\xc2\xcd\x6b\x69\x84\x77\x1f\xc9\x43\x62\x6e\x8d\x84\x19\xb5\xba\x52\x5e\x31\x21\xff\x08\x9d\xa2\xd2\x12\x97\xbc\x8d\x0e\xa9\xf3\xa6\x1e\x0b\xe2\x10\x21\xcc\x0c\x93\x43\xfb\xad\x47\x02\x6e\xac\x81\x01\x52\x91\x16\x8f\x49\x35\xb7\x18', 2)

# cleanup
del pyarmor_runtime

